@@ -76,7 +76,7 @@ def parse_arguments():
         "-j",
         "--max-concurrent-downloads",
         action="store",
-        default=3,
+        default=2,
         help="Set maximum number of parallel downloads.",
         metavar="MAX_WORKERS",
         dest="max_workers",
@@ -94,6 +94,16 @@ def parse_arguments():
         type=int,
     )
 
+    parser.add_argument(
+        "--sleep-interval",
+        action="store",
+        default=1,
+        help="Sleep between downloads in seconds. (Default: 1s)",
+        metavar="INTERVAL",
+        dest="sleep_interval",
+        type=int,
+    )
+
     parser.add_argument(
         "-q",
         "--quiet",
